@@ -3,8 +3,5 @@
 #undef HAVE_GETTEXT
 #undef HAVE_LC_MESSAGES
 #undef HAVE_STPCPY
+#undef GETTEXT_PACKAGE
 
-#undef HAVE_RPM_4_0
-#undef WITH_DPKG
-#undef WITH_RPM3
-#undef WITH_RPM4
