@@ -70,11 +70,7 @@ druid_set_sensitive (gboolean prev, gboolean next, gboolean cancel)
 void
 on_druid_help_clicked (GtkWidget *w, gpointer data)
 {
-#ifdef FIXME
-	GnomeHelpMenuEntry help_entry = { "bug-buddy", NULL };
-	help_entry.path = help_pages[druid_data.state];
-	gnome_help_display (NULL, &help_entry);
-#endif
+	gnome_help_display ("bug-buddy", NULL, NULL);
 }
 
 void
@@ -219,11 +215,20 @@ druid_set_state (BuddyState state)
 void
 on_druid_prev_clicked (GtkWidget *w, gpointer data)
 {
-	if (druid_data.state == STATE_DESC && 
-	    GTK_TOGGLE_BUTTON (GET_WIDGET ("no-product-toggle"))->active)
-		druid_set_state (STATE_PRODUCT);
-	else
-		druid_set_state (druid_data.state - 1);
+	BuddyState newstate = druid_data.state - 1;
+
+	switch (druid_data.state) {
+	case STATE_DESC:
+		if (GTK_TOGGLE_BUTTON (GET_WIDGET ("no-product-toggle"))->active)
+			newstate = STATE_PRODUCT;
+		else if (!druid_data.product->bts->bugs)
+			newstate = STATE_COMPONENT;
+		break;
+	default:
+		break;
+	}
+
+	druid_set_state (newstate);
 }
 
 
@@ -484,15 +489,24 @@ submit_ok (void)
 	GtkWidget *w;
 	FILE *fp;
 
+	enum {
+		RESPONSE_SUBMIT,
+		RESPONSE_CANCEL
+	};
+
 	if (druid_data.submit_type != SUBMIT_FILE) {
 		w = gtk_message_dialog_new (GTK_WINDOW (GET_WIDGET ("druid-window")),
 					    0,
 					    GTK_MESSAGE_QUESTION,
-					    GTK_BUTTONS_YES_NO,
+					    GTK_BUTTONS_NONE,
 					    _("Submit this bug report now?"));
+		gtk_dialog_add_buttons (GTK_DIALOG (w),
+					GTK_STOCK_CANCEL, RESPONSE_CANCEL,
+					_("_Submit"), RESPONSE_SUBMIT,
+					NULL);
 		gtk_dialog_set_default_response (GTK_DIALOG (w),
 						 GTK_RESPONSE_YES);
-		if (GTK_RESPONSE_YES != gtk_dialog_run (GTK_DIALOG (w))) {
+		if (RESPONSE_SUBMIT != gtk_dialog_run (GTK_DIALOG (w))) {
 			gtk_widget_destroy (w);
 			return FALSE;
 		}
@@ -697,6 +711,8 @@ on_druid_next_clicked (GtkWidget *w, gpointer data)
 			druid_data.component = component;
 			bugzilla_add_mostfreq (druid_data.product->bts);
 		}
+		if (!druid_data.product->bts->bugs)
+			newstate++;
 		break;
 	}
 	case STATE_MOSTFREQ:
